@@ -1,5 +1,5 @@
 # This file is part of shinystan
-# Copyright (C) Jonah Gabry
+# Copyright (C) 2015 Jonah Gabry
 #
 # shinystan is free software; you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software
@@ -34,6 +34,7 @@ tagList(
              inverse = FALSE, position = "fixed-top",
              theme = shinythemes::shinytheme("flatly"),
              
+             #### HOME PAGE ####
              tabPanel(title = strong(style = "color: #B2011D;", "ShinyStan"),
                       value = "home",
                       logo_and_name(),
@@ -51,7 +52,6 @@ tagList(
              #### PAGE: DIAGNOSE ####
              tabPanel(title = "Diagnose", icon = icon("medkit"),
                       tabsetPanel(
-                        
                         #### hmc/nuts plots ####
                         tabPanel("NUTS (plots)",
                                  source(file.path("ui_files", "diagnostics_customize.R"), local = TRUE)$value,
@@ -64,7 +64,7 @@ tagList(
                                               tabPanel("Help", source(file.path("ui_files", "diagnostics_help.R"), local = TRUE)$value),
                                               well = FALSE,
                                               widths = c(2, 10)
-                                 ) # End navlistPanel
+                                 )
                         ),
                         #### hmc/nuts stats ####
                         tabPanel("HMC/NUTS (stats)",
@@ -95,10 +95,9 @@ tagList(
                         tabPanel(title = "PPcheck", 
                                  h2("Graphical posterior predictive checks"),
                                  h6("Experimental feature"),
-                                 source(file.path("ui_files", "pp_navlist.R"), local = TRUE)$value,
+                                 source(file.path("ui_files", if (.from_rstanarm) "pp_navlist_rstanarm.R" else "pp_navlist.R"), local = TRUE)$value,
                                  br()
                         )
-                        
                       ) # End tabsetPanel
              ), # End DIAGNOSE
              
@@ -108,7 +107,7 @@ tagList(
                       
                       tabsetPanel(
                         #### multiparameter plot ####
-                        tabPanel("Parameters plot", #icon = icon("bar-chart-o", "fa-2x"),
+                        tabPanel("Parameters plot",
                                  wellPanel(
                                    fluidRow(
                                      column(6, uiOutput("ui_multiparam_selectize")),
@@ -117,18 +116,24 @@ tagList(
                                                         width = "75%", ticks = FALSE, min = 50, max = 95, 
                                                         value = 50, step = 5, post = "%")),
                                      column(2, a_options("multiparam"))
+                                   ),
+                                   fluidRow(
+                                     column(1, actionButton("param_plot_regex", label = "Search", class = "regex-go")),
+                                     column(3, textInput("params_to_plot_regex", label = NULL, value = "Add parameters by regex search")),
+                                     column(5, textOutput("invalid_regex"))
                                    )
                                  ),
                                  source(file.path("ui_files", "multiparam_customize.R"), local = TRUE)$value,
                                  plotOutput("multiparam_plot_out", width = "90%")
                         ),
                         #### posterior summary statistics ####
-                        tabPanel("Posterior summary statistics", #icon = icon("table", "fa-2x"),
+                        tabPanel("Posterior summary statistics",
                                  source(file.path("ui_files", "table_customize.R"), local = TRUE)$value,
                                  div(DT::dataTableOutput("all_summary_out"), 
                                      style = "overflow-x: auto")
                         ),
-                        tabPanel("Generate LaTeX table", #icon = icon("table", "fa-2x"),
+                        #### LaTex tables ####
+                        tabPanel("Generate LaTeX table",
                                  br(),
                                  sidebarLayout(
                                    mainPanel = source(file.path("ui_files", "table_latex_main.R"), local = TRUE)$value,
@@ -202,47 +207,41 @@ tagList(
                                             downloadButton("download_histogram", "ggplot2",  class = "plot-download"),
                                             downloadButton('save_pdf_histogram', "pdf", class = "plot-download pdf-download")
                                    )
-                                   
                       ) # End navlist
              ), # End EXPLORE
              
              #### MENU: More ####
              navbarMenu(title = "More",
                         
-                        #### PAGE: Model Code ####
+                        #### model code ####
                         tabPanel(title = "Model Code", 
                                  source(file.path("ui_files", "model_code.R"), local = TRUE)$value
-                        ), # End Model Code
-                        
-                        #### PAGE: Notepad ####
+                        ), 
+                        #### notepad ####
                         tabPanel(title = "Notepad",
                                  source(file.path("ui_files", "notepad.R"), local = TRUE)$value
-                        ), # End Notepad
-                        
-                        #### PAGE: About ####
+                        ),
+                        #### about ####
                         tabPanel(title = "About", 
                                  logo_and_name(),
                                  div(style = "margin-top: 75px;",
                                      source(file.path("ui_files", "about.R"), local = TRUE)$value
-                                   )
-                        ), # End About
-                        
+                                 )
+                        ),
+                        #### glossary ####
                         tabPanel(title = "Glossary",
                                  div(style = "background-color: white;",
-                                 h1(style = "text-align: center;", "Glossary"),
-                                 source(file.path("ui_files", "glossary.R"), local = TRUE)$value,
-                                 hr(),
-                                 stan_manual()
+                                     h1(style = "text-align: center;", "Glossary"),
+                                     source(file.path("ui_files", "glossary.R"), local = TRUE)$value,
+                                     hr(),
+                                     stan_manual()
                                  )
-                                 ),
-                        
-                        #### PAGE: Help ####
+                        ),
+                        #### help ####
                         tabPanel(title = "Help",
                                  h1(style = "text-align: center;", "Help"),
                                  source(file.path("ui_files", "help.R"), local = TRUE)$value
                         )
-                        
              ) # End navbarMenu
-
   ) # End navbarPage
 ) # End tagList
